@@ -507,7 +507,7 @@ except ImportError:
 
 if not available_solvers:
     raise ImportError(
-        "no QP solver found, you can install some by running:\n\n"
+        "no QP solver found, you can install open source solvers by:\n\n"
         "\tpip install qpsolvers[open_source_solvers]\n"
     )
 
