@@ -19,10 +19,10 @@
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
 import unittest
+import warnings
 
 from .problems import get_sd3310_problem
 
-
 try:
     from qpsolvers.solvers.gurobi_ import gurobi_solve_qp
 
@@ -45,6 +45,5 @@ try:
             self.assertIsNotNone(x)
 
 
-except ImportError:  # ProxSuite not installed
-
-    pass
+except ImportError:  # solver not installed
+    warnings.warn("Skipping Gurobi tests as the solver is not installed")
