@@ -19,20 +19,35 @@
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
 import unittest
+import warnings
 
-from qpsolvers.solvers import qpswift_solve_qp
+import scipy.sparse as spa
+
+from qpsolvers import ProblemError
 
 from .problems import get_sd3310_problem
 
+try:
+    from qpsolvers.solvers.qpswift_ import qpswift_solve_qp
 
-class TestQpSwift(unittest.TestCase):
+    class TestQpSwift(unittest.TestCase):
 
-    """
-    Tests specific to qpSWIFT.
-    """
+        """
+        Tests specific to qpSWIFT.
+        """
 
-    def test_problem(self):
-        problem = get_sd3310_problem()
-        P, q, G, h, A, b, lb, ub = problem.unpack()
-        if qpswift_solve_qp is not None:
+        def test_problem(self):
+            problem = get_sd3310_problem()
+            P, q, G, h, A, b, lb, ub = problem.unpack()
             self.assertIsNotNone(qpswift_solve_qp(P, q, G, h, A, b, lb, ub))
+
+        def test_not_sparse(self):
+            problem = get_sd3310_problem()
+            P, q, G, h, A, b, lb, ub = problem.unpack()
+            P = spa.csc_matrix(P)
+            with self.assertRaises(ProblemError):
+                qpswift_solve_qp(P, q, G, h, A, b, lb, ub)
+
+
+except ImportError:  # solver not installed
+    warnings.warn("Skipping qpSWIFT tests as the solver is not installed")
